switchboard_pyramid is a wrapper around `Switchboard <https://pypi.python.org/pypi/switchboard>`_, turning it into a
pyramid add-on and making it super easy to use with your pyramid apps.
Switchboard is a feature flipper, allowing you to control what features
or blocks of code are active for any given request.
